@@ -508,11 +508,13 @@ class Declaration:
         self.property = ""
         self.value = ""
         self.invalid_message = ""
+        self.is_color = False
         # validate before trying to set the declaration.
         try:
             self.validate_declaration()
             self.is_valid = True
             self.set_declaration()
+            self.is_color_property()
         except ValueError as e:
             self.is_valid = False
             self.invalid_message = str(e)
@@ -632,6 +634,12 @@ class Declaration:
         declaration = self.property + ": " + self.value
         return declaration
 
+    def is_color_property(self):
+        value = self.value
+        if value[-1] == ";":
+            value = value[:-1]
+        self.is_color = color_tools.is_color_value(value)
+
 
 def restore_braces(split: list) -> list:
     """restore the missing braces removed by the .split() method
@@ -1230,7 +1238,7 @@ def get_colors_from_gradient(gradient: str) -> list:
 
 
 def get_color_codes_of_type(color_type: str, gradient: str) -> list:
-    """returns all color codes of a particular type (hsl, rgb, etc.)
+    """returns all color codes of a particular type from a gradient
 
     Args:
         color_type: the type of color code it might be (hex, rgb, hsl,
@@ -1537,6 +1545,96 @@ def adjust_overrides(file_path: str, rules: dict) -> dict:
     return adjusted_rule
 
 
+def get_all_color_rules(stylesheet: Stylesheet) -> list:
+    """Gets all color-based rules from a stylesheet.
+
+    Args:
+        stylesheet: Stylesheet object.
+
+    Returns:
+        rules: a list of color-based rules"""
+    rules = []
+    for ruleset in stylesheet.rulesets:
+        declaration_block = ruleset.declaration_block
+        declarations = declaration_block.declarations
+        for declaration in declarations:
+            property = declaration.property
+            if property == "color" or "background" in property:
+                selector = ruleset.selector
+                value = declaration.value
+                if property == "background":
+                    background_color = get_background_color(declaration)
+                    if not background_color:
+                        continue
+                    else:
+                        value = background_color
+                rules.append((selector, property, value))
+    return rules
+
+
+def get_background_color(declaration: Declaration) -> Union[str, None]:
+    """Returns a color value from a declaration with a property of background
+
+    Args:
+        declaration: the declaration we want to test.
+
+    Returns:
+        color_value: either a valid color value, None, or gradient - if it's a
+            gradient"""
+    color_value = None
+    is_rgb = color_tools.is_rgb(declaration.value)
+    if is_rgb:
+        return declaration.value
+    values = declaration.value.split()
+    for val in values:
+        color = color_tools.is_color_value(val)
+        if color:
+            color_value = val
+            break
+        is_keyword = val in color_tools.color_keywords.get_all_keywords()
+        if is_keyword:
+            color_value = val
+            break
+        gradient = is_gradient(val)
+        if gradient:
+            color_value = "gradient"
+            break
+    return color_value
+
+
+def condense_the_rules(rules):
+    condensed = []
+    for rule in rules:
+        file, sel, prop, val = rule
+        color = {}
+        background = {}
+        declaration = get_bg_or_color(prop)
+        if declaration.get("type") == "color":
+            color = declaration
+        elif declaration.get("type") == "background":
+            background = declaration
+        if not condensed:
+            condensed.append([file, sel, color, background, val])
+        else:
+            for rule in condensed:
+                cur_file, cur_sel, cur_col, cur_bg_col, cur_val = rule
+                if file == cur_file and sel == cur_sel:
+                    # add the property that is missing (if it is missing)
+                    print("It's time to work.")
+    return condensed
+
+
+def get_bg_or_color(prop):
+    declaration = {"type": {}, "declaration": {}}
+    if prop == "color":
+        declaration["type"] = "color"
+        declaration["declaration"] = {"color": prop}
+    if "background" in prop:
+        declaration["type"] = "background"
+        declaration["declaration"] = {"background": prop}
+    return declaration
+
+
 if __name__ == "__main__":
     insane_gradient = """
     -moz-radial-gradient(0% 200%, ellipse cover,
